summaryrefslogtreecommitdiff
path: root/lib/HttpServ.cc
diff options
context:
space:
mode:
Diffstat (limited to 'lib/HttpServ.cc')
-rw-r--r--lib/HttpServ.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/HttpServ.cc b/lib/HttpServ.cc
index a4101a7..a923c83 100644
--- a/lib/HttpServ.cc
+++ b/lib/HttpServ.cc
@@ -165,11 +165,11 @@ int ProcessRequest::Do() throw(GeneralException) {
ShowError(&b);
}
} else {
// Dans tous les autres cas de domaine, on cherche le fichier dans le répertoire datas.
// On utilise try au cas où le fichier n'existe pas et donc que le constructeur
// d'input renvoie une erreur.
try {
- Handle * i = new Input(String("datas/") + file);
+ Handle * i = new Input(String("data/") + file);
SendHeads(&b, GetMime(file), String("Accept-Ranges: bytes") + endhl + "Content-Length: " + (unsigned long long int) i->GetSize() + endhl, i->GetModif());
i->SetNonBlock();
a = new CopyJob(i, &s);
@@ -165,11 +165,11 @@ int ProcessRequest::Do() throw(GeneralException) {
}
} else {
- // Dans tous les autres cas de domaine, on cherche le fichier dans le répertoire datas.
+ // Dans tous les autres cas de domaine, on cherche le fichier dans le répertoire data.
// On utilise try au cas où le fichier n'existe pas et donc que le constructeur
// d'input renvoie une erreur.